/********************************************************************************
** Form generated from reading UI file 'PaintBrushSettingsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.10.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PAINTBRUSHSETTINGSWIDGET_H
#define UI_PAINTBRUSHSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PaintBrushSettingsWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *labelPressureValue;
    QLabel *labelRadiusValue;
    QLabel *labelRadius;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    QCheckBox *cbAntialias;
    QSlider *sliderRadius;
    QSlider *pressureSlider;
    QToolButton *buttonRoundCap;
    QToolButton *buttonSquareCap;

    void setupUi(QWidget *PaintBrushSettingsWidget)
    {
        if (PaintBrushSettingsWidget->objectName().isEmpty())
            PaintBrushSettingsWidget->setObjectName("PaintBrushSettingsWidget");
        PaintBrushSettingsWidget->resize(134, 213);
        gridLayout = new QGridLayout(PaintBrushSettingsWidget);
        gridLayout->setObjectName("gridLayout");
        labelPressureValue = new QLabel(PaintBrushSettingsWidget);
        labelPressureValue->setObjectName("labelPressureValue");

        gridLayout->addWidget(labelPressureValue, 4, 2, 1, 1);

        labelRadiusValue = new QLabel(PaintBrushSettingsWidget);
        labelRadiusValue->setObjectName("labelRadiusValue");

        gridLayout->addWidget(labelRadiusValue, 2, 2, 1, 1);

        labelRadius = new QLabel(PaintBrushSettingsWidget);
        labelRadius->setObjectName("labelRadius");

        gridLayout->addWidget(labelRadius, 2, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 0, 1, 1, 1);

        label = new QLabel(PaintBrushSettingsWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 4, 0, 1, 2);

        cbAntialias = new QCheckBox(PaintBrushSettingsWidget);
        cbAntialias->setObjectName("cbAntialias");

        gridLayout->addWidget(cbAntialias, 6, 0, 1, 3);

        sliderRadius = new QSlider(PaintBrushSettingsWidget);
        sliderRadius->setObjectName("sliderRadius");
        sliderRadius->setMinimum(1);
        sliderRadius->setOrientation(Qt::Horizontal);
        sliderRadius->setTickPosition(QSlider::TicksBelow);

        gridLayout->addWidget(sliderRadius, 3, 0, 1, 3);

        pressureSlider = new QSlider(PaintBrushSettingsWidget);
        pressureSlider->setObjectName("pressureSlider");
        pressureSlider->setMinimum(10);
        pressureSlider->setMaximum(100);
        pressureSlider->setSingleStep(10);
        pressureSlider->setValue(100);
        pressureSlider->setOrientation(Qt::Horizontal);
        pressureSlider->setTickPosition(QSlider::TicksBelow);
        pressureSlider->setTickInterval(10);

        gridLayout->addWidget(pressureSlider, 5, 0, 1, 3);

        buttonRoundCap = new QToolButton(PaintBrushSettingsWidget);
        buttonRoundCap->setObjectName("buttonRoundCap");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/brushes/assets/brushes/circle.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        buttonRoundCap->setIcon(icon);
        buttonRoundCap->setIconSize(QSize(32, 32));
        buttonRoundCap->setCheckable(true);
        buttonRoundCap->setChecked(true);

        gridLayout->addWidget(buttonRoundCap, 1, 0, 1, 1);

        buttonSquareCap = new QToolButton(PaintBrushSettingsWidget);
        buttonSquareCap->setObjectName("buttonSquareCap");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/brushes/assets/brushes/square.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        buttonSquareCap->setIcon(icon1);
        buttonSquareCap->setIconSize(QSize(32, 32));
        buttonSquareCap->setCheckable(true);
        buttonSquareCap->setChecked(false);

        gridLayout->addWidget(buttonSquareCap, 1, 2, 1, 1);

#if QT_CONFIG(shortcut)
        labelRadius->setBuddy(sliderRadius);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PaintBrushSettingsWidget);

        QMetaObject::connectSlotsByName(PaintBrushSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *PaintBrushSettingsWidget)
    {
        PaintBrushSettingsWidget->setWindowTitle(QCoreApplication::translate("PaintBrushSettingsWidget", "Form", nullptr));
        labelPressureValue->setText(QCoreApplication::translate("PaintBrushSettingsWidget", "100", nullptr));
        labelRadiusValue->setText(QCoreApplication::translate("PaintBrushSettingsWidget", "0", nullptr));
        labelRadius->setText(QCoreApplication::translate("PaintBrushSettingsWidget", "&Radius:", nullptr));
        label->setText(QCoreApplication::translate("PaintBrushSettingsWidget", "Pressure", nullptr));
        cbAntialias->setText(QCoreApplication::translate("PaintBrushSettingsWidget", "&Anti-aliasing", nullptr));
        buttonRoundCap->setText(QCoreApplication::translate("PaintBrushSettingsWidget", "...", nullptr));
        buttonSquareCap->setText(QCoreApplication::translate("PaintBrushSettingsWidget", "...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PaintBrushSettingsWidget: public Ui_PaintBrushSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PAINTBRUSHSETTINGSWIDGET_H
