/****************************************************************************
** Meta object code from reading C++ file 'PointerTool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "src/tools/PointerTool.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PointerTool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PointerToolE_t {};
} // unnamed namespace

template <> constexpr inline auto PointerTool::qt_create_metaobjectdata<qt_meta_tag_ZN11PointerToolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PointerTool",
        "crop",
        "",
        "QRect",
        "strokeRect",
        "QColor",
        "fillRect",
        "save",
        "saveAs",
        "close",
        "imageSize",
        "canvasSize",
        "copy",
        "paste",
        "undo",
        "redo",
        "showhotspots",
        "onCrop",
        "onStrokeRect",
        "onFillRect",
        "onSave",
        "onSaveAs",
        "onClose",
        "onImageSize",
        "onCanvasSize",
        "onCopy",
        "onPaste",
        "onUndo",
        "onRedo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'crop'
        QtMocHelpers::SignalData<void(const QRect &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'strokeRect'
        QtMocHelpers::SignalData<void(const QRect &, const QColor &, const int &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 5, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'fillRect'
        QtMocHelpers::SignalData<void(const QRect &, const QColor &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 5, 2 },
        }}),
        // Signal 'save'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveAs'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'close'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageSize'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canvasSize'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copy'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paste'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undo'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redo'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showhotspots'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCrop'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onStrokeRect'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFillRect'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSave'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSaveAs'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onClose'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onImageSize'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCanvasSize'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCopy'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPaste'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onUndo'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onRedo'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PointerTool, qt_meta_tag_ZN11PointerToolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PointerTool::staticMetaObject = { {
    QMetaObject::SuperData::link<Tool::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PointerToolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PointerToolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PointerToolE_t>.metaTypes,
    nullptr
} };

void PointerTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PointerTool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->crop((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 1: _t->strokeRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->fillRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 3: _t->save(); break;
        case 4: _t->saveAs(); break;
        case 5: _t->close(); break;
        case 6: _t->imageSize(); break;
        case 7: _t->canvasSize(); break;
        case 8: _t->copy(); break;
        case 9: _t->paste(); break;
        case 10: _t->undo(); break;
        case 11: _t->redo(); break;
        case 12: _t->showhotspots(); break;
        case 13: _t->onCrop(); break;
        case 14: _t->onStrokeRect(); break;
        case 15: _t->onFillRect(); break;
        case 16: _t->onSave(); break;
        case 17: _t->onSaveAs(); break;
        case 18: _t->onClose(); break;
        case 19: _t->onImageSize(); break;
        case 20: _t->onCanvasSize(); break;
        case 21: _t->onCopy(); break;
        case 22: _t->onPaste(); break;
        case 23: _t->onUndo(); break;
        case 24: _t->onRedo(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)(const QRect & )>(_a, &PointerTool::crop, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)(const QRect & , const QColor & , const int & )>(_a, &PointerTool::strokeRect, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)(const QRect & , const QColor & )>(_a, &PointerTool::fillRect, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::save, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::saveAs, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::close, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::imageSize, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::canvasSize, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::copy, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::paste, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::undo, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::redo, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PointerTool::*)()>(_a, &PointerTool::showhotspots, 12))
            return;
    }
}

const QMetaObject *PointerTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PointerTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PointerToolE_t>.strings))
        return static_cast<void*>(this);
    return Tool::qt_metacast(_clname);
}

int PointerTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Tool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void PointerTool::crop(const QRect & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PointerTool::strokeRect(const QRect & _t1, const QColor & _t2, const int & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void PointerTool::fillRect(const QRect & _t1, const QColor & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void PointerTool::save()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PointerTool::saveAs()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PointerTool::close()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PointerTool::imageSize()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PointerTool::canvasSize()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PointerTool::copy()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PointerTool::paste()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PointerTool::undo()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PointerTool::redo()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void PointerTool::showhotspots()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
