/****************************************************************************
** Meta object code from reading C++ file 'Tool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "src/tools/Tool.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Tool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4ToolE_t {};
} // unnamed namespace

template <> constexpr inline auto Tool::qt_create_metaobjectdata<qt_meta_tag_ZN4ToolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Tool",
        "cursorChanged",
        "",
        "QCursor",
        "selectionChanged",
        "QPolygon",
        "painted",
        "QPaintDevice*",
        "paintDevice",
        "overlaid",
        "QImage",
        "overlayImage",
        "QPainter::CompositionMode",
        "mode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cursorChanged'
        QtMocHelpers::SignalData<void(QCursor)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void(QPolygon)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'painted'
        QtMocHelpers::SignalData<void(QPaintDevice *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'overlaid'
        QtMocHelpers::SignalData<void(QPaintDevice *, const QImage &, QPainter::CompositionMode)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Tool, qt_meta_tag_ZN4ToolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Tool::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4ToolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4ToolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4ToolE_t>.metaTypes,
    nullptr
} };

void Tool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Tool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cursorChanged((*reinterpret_cast<std::add_pointer_t<QCursor>>(_a[1]))); break;
        case 1: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QPolygon>>(_a[1]))); break;
        case 2: _t->painted((*reinterpret_cast<std::add_pointer_t<QPaintDevice*>>(_a[1]))); break;
        case 3: _t->overlaid((*reinterpret_cast<std::add_pointer_t<QPaintDevice*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QImage>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPainter::CompositionMode>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Tool::*)(QCursor )>(_a, &Tool::cursorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tool::*)(QPolygon )>(_a, &Tool::selectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tool::*)(QPaintDevice * )>(_a, &Tool::painted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tool::*)(QPaintDevice * , const QImage & , QPainter::CompositionMode )>(_a, &Tool::overlaid, 3))
            return;
    }
}

const QMetaObject *Tool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Tool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4ToolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Tool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Tool::cursorChanged(QCursor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Tool::selectionChanged(QPolygon _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Tool::painted(QPaintDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Tool::overlaid(QPaintDevice * _t1, const QImage & _t2, QPainter::CompositionMode _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
