/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "src/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "handleMessage",
        "",
        "message",
        "onImageFiltered",
        "QImage",
        "image",
        "setupWorkspace",
        "addZoomCombo",
        "connectTools",
        "addSettingsWidgets",
        "on_actionNew_triggered",
        "on_actionOpen_triggered",
        "on_actionSave_triggered",
        "on_actionSave_As_triggered",
        "on_actionText_triggered",
        "on_actionPreferences_triggered",
        "on_toolButtonPointer_clicked",
        "on_toolButtonDropper_clicked",
        "on_toolButtonWand_clicked",
        "on_toolButtonLine_clicked",
        "on_toolButtonPaintBucket_clicked",
        "on_toolButtonSprayCan_clicked",
        "on_toolButtonPaintBrush_clicked",
        "on_toolButtonPaintBrushAdv_clicked",
        "on_toolButtonStamp_clicked",
        "on_toolButtonBlur_clicked",
        "on_toolButtonEraser_clicked",
        "on_toolButtonSmudge_clicked",
        "clearToolpalette",
        "on_actionQuit_triggered",
        "on_actionOil_Paint_triggered",
        "on_actionCharcoal_Drawing_triggered",
        "on_actionClose_triggered",
        "on_actionClose_all_triggered",
        "refreshTools",
        "on_actionAbout_triggered",
        "setWindowSize",
        "updateRecentFilesMenu",
        "showError",
        "onPointerToolSettingsChanged",
        "onPaintBrushSettingsChanged",
        "onPaintBrushAdvSettingsChanged",
        "onSprayCanSettingsChanged",
        "onLineSettingsChanged",
        "onMagicWandSettingsChanged",
        "onStampSettingsChanged",
        "onBlurSettingsChanged",
        "onEraserSettingsChanged",
        "onSmudgeSettingsChanged",
        "onPickPrimaryColor",
        "QPoint",
        "onPickSecondaryColor",
        "onFloodFillPrimaryColor",
        "onFloodFillSecondaryColor",
        "onSelectPrimaryColor",
        "onCrop",
        "QRect",
        "onStrokeRect",
        "QColor",
        "onFillRect",
        "onCopy",
        "onPaste",
        "on_actionPaste_as_new_image_triggered",
        "onZoomChanged",
        "onSubWindowActivated",
        "QMdiSubWindow*",
        "onEditText",
        "QFont",
        "onTextToolFinished",
        "onMultiWindowModeChanged",
        "on_actionSwirl_triggered",
        "on_actionGrayScale_triggered",
        "on_actionFlip_Vertical_triggered",
        "on_actionFlip_Horizontal_triggered",
        "on_actionRotate_CCW_triggered",
        "on_actionRotate_CW_triggered",
        "on_actionFree_Rotate_triggered",
        "on_actionImage_Size_triggered",
        "on_actionFilterbar_triggered",
        "on_actionToolpalette_triggered",
        "on_actionZoom_in_triggered",
        "on_actionZoom_out_triggered",
        "on_actionUndo_triggered",
        "on_actionRedo_triggered",
        "on_actionPrint_triggered",
        "on_actionFull_screen_triggered",
        "on_actionOriginal_size_triggered",
        "on_actionSolarize_triggered",
        "on_actionWave_triggered",
        "on_actionImplode_triggered",
        "on_actionSoften_triggered",
        "on_actionBlur_triggered",
        "on_actionSharpen_triggered",
        "on_actionReinforce_triggered",
        "on_actionImage_properties_triggered",
        "on_actionAutomate_Batch_triggered",
        "on_actionShow_selection_triggered",
        "checked",
        "on_actionCanvas_Size_triggered",
        "on_actionRevert_triggered",
        "on_actionBrightplus_triggered",
        "on_actionBrightminus_triggered",
        "on_actionContrastplus_triggered",
        "on_actionContrastminus_triggered",
        "on_actionGammaCorrectplus_triggered",
        "on_actionGammaCorrectminus_triggered",
        "on_actionSaturationplus_triggered",
        "on_actionSaturationminus_triggered",
        "on_actionOldPhoto_triggered",
        "on_actionDustReduction_triggered",
        "on_actionOutside_frame_triggered",
        "on_actionEmboss_triggered",
        "on_actionGaussian_triggered",
        "on_actionImpulse_triggered",
        "on_actionLaplacian_triggered",
        "on_actionPoisson_triggered",
        "on_actionMonoChromatic_triggered",
        "on_actionEqualize_triggered",
        "on_actionCrop_To_Center_triggered",
        "on_actionAdd_Simple_Frame_triggered",
        "on_actionMotion_blur_triggered",
        "on_actionNormalize_triggered",
        "on_action3D_frame_triggered",
        "on_actionExplode_triggered",
        "on_actionDespeckle_triggered",
        "on_actionSepia_triggered",
        "on_actionAuto_levels_triggered",
        "on_actionAuto_contrast_triggered",
        "batchProcess_fileProcessFinished",
        "file",
        "batchProcess_batchProgress",
        "index",
        "total",
        "on_actionHue_variation_triggered",
        "onHuePreviewChanged",
        "colorize",
        "color",
        "degrees",
        "onPreviewTransparent",
        "tolerance",
        "onTransparentFinished",
        "onTransparentAccepted",
        "onTransparentRejected",
        "on_actionGradient_triggered",
        "on_actionCrop_triggered",
        "on_actionStroke_Rect_triggered",
        "on_actionFill_Rect_triggered",
        "onSelectionChanged",
        "visible",
        "on_actionPaste_triggered",
        "on_actionCopy_triggered",
        "on_actionTransparent_colour_triggered",
        "on_actionIndexed_Mode_triggered",
        "on_actionRGB_Mode_triggered",
        "on_actionDonate_triggered",
        "on_actionAutomatic_Crop_triggered",
        "on_actionNegative_triggered",
        "on_actionBlack_and_white_triggered",
        "fileExists",
        "path",
        "on_actionOutside_drop_shadow_triggered",
        "on_actionOpacity_triggered",
        "on_actionPlugins_triggered",
        "on_actionCheck_for_updates_triggered",
        "onShowHotspotsTriggered",
        "on_actionSelect_all_triggered",
        "on_actionColour_Threshold_triggered",
        "on_actionClearHistory_triggered",
        "on_actionClearClipboard_triggered",
        "on_actionDuplicate_triggered",
        "on_actionShow_grid_triggered",
        "prepareFile",
        "fileName",
        "fileTypeSupported",
        "QList<QByteArray>",
        "formats",
        "ext",
        "getNextZoomFromScale",
        "scaletext",
        "getPrevZoomFromScale",
        "onSafeQuitApp"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleMessage'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onImageFiltered'
        QtMocHelpers::SlotData<void(QImage)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setupWorkspace'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addZoomCombo'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'connectTools'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addSettingsWidgets'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionNew_triggered'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOpen_triggered'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSave_triggered'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSave_As_triggered'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionText_triggered'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionPreferences_triggered'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonPointer_clicked'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonDropper_clicked'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonWand_clicked'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonLine_clicked'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonPaintBucket_clicked'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonSprayCan_clicked'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonPaintBrush_clicked'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonPaintBrushAdv_clicked'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonStamp_clicked'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonBlur_clicked'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonEraser_clicked'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButtonSmudge_clicked'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearToolpalette'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionQuit_triggered'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOil_Paint_triggered'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCharcoal_Drawing_triggered'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionClose_triggered'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionClose_all_triggered'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshTools'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAbout_triggered'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWindowSize'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRecentFilesMenu'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showError'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onPointerToolSettingsChanged'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPaintBrushSettingsChanged'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPaintBrushAdvSettingsChanged'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSprayCanSettingsChanged'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLineSettingsChanged'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMagicWandSettingsChanged'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onStampSettingsChanged'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBlurSettingsChanged'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onEraserSettingsChanged'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSmudgeSettingsChanged'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPickPrimaryColor'
        QtMocHelpers::SlotData<void(const QPoint &)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'onPickSecondaryColor'
        QtMocHelpers::SlotData<void(const QPoint &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'onFloodFillPrimaryColor'
        QtMocHelpers::SlotData<void(const QPoint &)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'onFloodFillSecondaryColor'
        QtMocHelpers::SlotData<void(const QPoint &)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 },
        }}),
        // Slot 'onSelectPrimaryColor'
        QtMocHelpers::SlotData<void(const QPoint &, int, bool)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 2 }, { QMetaType::Int, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'onCrop'
        QtMocHelpers::SlotData<void(const QRect &)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 },
        }}),
        // Slot 'onStrokeRect'
        QtMocHelpers::SlotData<void(const QRect &, const QColor &, const int &)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 }, { 0x80000000 | 59, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'onFillRect'
        QtMocHelpers::SlotData<void(const QRect &, const QColor &)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 }, { 0x80000000 | 59, 2 },
        }}),
        // Slot 'onCopy'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPaste'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionPaste_as_new_image_triggered'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onZoomChanged'
        QtMocHelpers::SlotData<void(const QString &)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'onSubWindowActivated'
        QtMocHelpers::SlotData<void(QMdiSubWindow *)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 66, 2 },
        }}),
        // Slot 'onEditText'
        QtMocHelpers::SlotData<void(const QString &, const QFont &, const QColor &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 68, 2 }, { 0x80000000 | 59, 2 },
        }}),
        // Slot 'onTextToolFinished'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMultiWindowModeChanged'
        QtMocHelpers::SlotData<void(bool)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'on_actionSwirl_triggered'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionGrayScale_triggered'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFlip_Vertical_triggered'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFlip_Horizontal_triggered'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRotate_CCW_triggered'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRotate_CW_triggered'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFree_Rotate_triggered'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImage_Size_triggered'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFilterbar_triggered'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionToolpalette_triggered'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionZoom_in_triggered'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionZoom_out_triggered'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionUndo_triggered'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRedo_triggered'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionPrint_triggered'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFull_screen_triggered'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOriginal_size_triggered'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSolarize_triggered'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionWave_triggered'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImplode_triggered'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSoften_triggered'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionBlur_triggered'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSharpen_triggered'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionReinforce_triggered'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImage_properties_triggered'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAutomate_Batch_triggered'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShow_selection_triggered'
        QtMocHelpers::SlotData<void(bool)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 98 },
        }}),
        // Slot 'on_actionCanvas_Size_triggered'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRevert_triggered'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionBrightplus_triggered'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionBrightminus_triggered'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionContrastplus_triggered'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionContrastminus_triggered'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionGammaCorrectplus_triggered'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionGammaCorrectminus_triggered'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSaturationplus_triggered'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSaturationminus_triggered'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOldPhoto_triggered'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDustReduction_triggered'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOutside_frame_triggered'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionEmboss_triggered'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionGaussian_triggered'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionImpulse_triggered'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLaplacian_triggered'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionPoisson_triggered'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionMonoChromatic_triggered'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionEqualize_triggered'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCrop_To_Center_triggered'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAdd_Simple_Frame_triggered'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionMotion_blur_triggered'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionNormalize_triggered'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_action3D_frame_triggered'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExplode_triggered'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDespeckle_triggered'
        QtMocHelpers::SlotData<void()>(125, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSepia_triggered'
        QtMocHelpers::SlotData<void()>(126, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAuto_levels_triggered'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAuto_contrast_triggered'
        QtMocHelpers::SlotData<void()>(128, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'batchProcess_fileProcessFinished'
        QtMocHelpers::SlotData<void(QString, QImage)>(129, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 130 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'batchProcess_batchProgress'
        QtMocHelpers::SlotData<void(int, int)>(131, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 132 }, { QMetaType::Int, 133 },
        }}),
        // Slot 'on_actionHue_variation_triggered'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHuePreviewChanged'
        QtMocHelpers::SlotData<void(QImage, bool, QColor, int)>(135, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Bool, 136 }, { 0x80000000 | 59, 137 }, { QMetaType::Int, 138 },
        }}),
        // Slot 'onPreviewTransparent'
        QtMocHelpers::SlotData<void(QColor, int)>(139, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 137 }, { QMetaType::Int, 140 },
        }}),
        // Slot 'onTransparentFinished'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTransparentAccepted'
        QtMocHelpers::SlotData<void()>(142, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTransparentRejected'
        QtMocHelpers::SlotData<void()>(143, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionGradient_triggered'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCrop_triggered'
        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionStroke_Rect_triggered'
        QtMocHelpers::SlotData<void()>(146, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFill_Rect_triggered'
        QtMocHelpers::SlotData<void()>(147, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void(bool)>(148, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 149 },
        }}),
        // Slot 'on_actionPaste_triggered'
        QtMocHelpers::SlotData<void()>(150, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopy_triggered'
        QtMocHelpers::SlotData<void()>(151, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionTransparent_colour_triggered'
        QtMocHelpers::SlotData<void()>(152, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionIndexed_Mode_triggered'
        QtMocHelpers::SlotData<void()>(153, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRGB_Mode_triggered'
        QtMocHelpers::SlotData<void()>(154, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDonate_triggered'
        QtMocHelpers::SlotData<void()>(155, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAutomatic_Crop_triggered'
        QtMocHelpers::SlotData<void()>(156, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionNegative_triggered'
        QtMocHelpers::SlotData<void()>(157, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionBlack_and_white_triggered'
        QtMocHelpers::SlotData<void()>(158, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fileExists'
        QtMocHelpers::SlotData<bool(QString)>(159, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::QString, 160 },
        }}),
        // Slot 'on_actionOutside_drop_shadow_triggered'
        QtMocHelpers::SlotData<void()>(161, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOpacity_triggered'
        QtMocHelpers::SlotData<void()>(162, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionPlugins_triggered'
        QtMocHelpers::SlotData<void()>(163, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCheck_for_updates_triggered'
        QtMocHelpers::SlotData<void()>(164, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowHotspotsTriggered'
        QtMocHelpers::SlotData<void()>(165, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSelect_all_triggered'
        QtMocHelpers::SlotData<void()>(166, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionColour_Threshold_triggered'
        QtMocHelpers::SlotData<void()>(167, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionClearHistory_triggered'
        QtMocHelpers::SlotData<void()>(168, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionClearClipboard_triggered'
        QtMocHelpers::SlotData<void()>(169, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDuplicate_triggered'
        QtMocHelpers::SlotData<void()>(170, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShow_grid_triggered'
        QtMocHelpers::SlotData<void()>(171, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'prepareFile'
        QtMocHelpers::SlotData<QString(const QString &)>(172, 2, QMC::AccessPrivate, QMetaType::QString, {{
            { QMetaType::QString, 173 },
        }}),
        // Slot 'fileTypeSupported'
        QtMocHelpers::SlotData<bool(QList<QByteArray>, QString)>(174, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 175, 176 }, { QMetaType::QString, 177 },
        }}),
        // Slot 'getNextZoomFromScale'
        QtMocHelpers::SlotData<void(QString)>(178, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 179 },
        }}),
        // Slot 'getPrevZoomFromScale'
        QtMocHelpers::SlotData<void(QString)>(180, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 179 },
        }}),
        // Slot 'onSafeQuitApp'
        QtMocHelpers::SlotData<void()>(181, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->onImageFiltered((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 2: _t->setupWorkspace(); break;
        case 3: _t->addZoomCombo(); break;
        case 4: _t->connectTools(); break;
        case 5: _t->addSettingsWidgets(); break;
        case 6: _t->on_actionNew_triggered(); break;
        case 7: _t->on_actionOpen_triggered(); break;
        case 8: _t->on_actionSave_triggered(); break;
        case 9: _t->on_actionSave_As_triggered(); break;
        case 10: _t->on_actionText_triggered(); break;
        case 11: _t->on_actionPreferences_triggered(); break;
        case 12: _t->on_toolButtonPointer_clicked(); break;
        case 13: _t->on_toolButtonDropper_clicked(); break;
        case 14: _t->on_toolButtonWand_clicked(); break;
        case 15: _t->on_toolButtonLine_clicked(); break;
        case 16: _t->on_toolButtonPaintBucket_clicked(); break;
        case 17: _t->on_toolButtonSprayCan_clicked(); break;
        case 18: _t->on_toolButtonPaintBrush_clicked(); break;
        case 19: _t->on_toolButtonPaintBrushAdv_clicked(); break;
        case 20: _t->on_toolButtonStamp_clicked(); break;
        case 21: _t->on_toolButtonBlur_clicked(); break;
        case 22: _t->on_toolButtonEraser_clicked(); break;
        case 23: _t->on_toolButtonSmudge_clicked(); break;
        case 24: _t->clearToolpalette(); break;
        case 25: _t->on_actionQuit_triggered(); break;
        case 26: _t->on_actionOil_Paint_triggered(); break;
        case 27: _t->on_actionCharcoal_Drawing_triggered(); break;
        case 28: _t->on_actionClose_triggered(); break;
        case 29: _t->on_actionClose_all_triggered(); break;
        case 30: _t->refreshTools(); break;
        case 31: _t->on_actionAbout_triggered(); break;
        case 32: _t->setWindowSize(); break;
        case 33: _t->updateRecentFilesMenu(); break;
        case 34: _t->showError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->onPointerToolSettingsChanged(); break;
        case 36: _t->onPaintBrushSettingsChanged(); break;
        case 37: _t->onPaintBrushAdvSettingsChanged(); break;
        case 38: _t->onSprayCanSettingsChanged(); break;
        case 39: _t->onLineSettingsChanged(); break;
        case 40: _t->onMagicWandSettingsChanged(); break;
        case 41: _t->onStampSettingsChanged(); break;
        case 42: _t->onBlurSettingsChanged(); break;
        case 43: _t->onEraserSettingsChanged(); break;
        case 44: _t->onSmudgeSettingsChanged(); break;
        case 45: _t->onPickPrimaryColor((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 46: _t->onPickSecondaryColor((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 47: _t->onFloodFillPrimaryColor((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 48: _t->onFloodFillSecondaryColor((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 49: _t->onSelectPrimaryColor((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 50: _t->onCrop((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 51: _t->onStrokeRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 52: _t->onFillRect((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 53: _t->onCopy(); break;
        case 54: _t->onPaste(); break;
        case 55: _t->on_actionPaste_as_new_image_triggered(); break;
        case 56: _t->onZoomChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 57: _t->onSubWindowActivated((*reinterpret_cast<std::add_pointer_t<QMdiSubWindow*>>(_a[1]))); break;
        case 58: _t->onEditText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFont>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3]))); break;
        case 59: _t->onTextToolFinished(); break;
        case 60: _t->onMultiWindowModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->on_actionSwirl_triggered(); break;
        case 62: _t->on_actionGrayScale_triggered(); break;
        case 63: _t->on_actionFlip_Vertical_triggered(); break;
        case 64: _t->on_actionFlip_Horizontal_triggered(); break;
        case 65: _t->on_actionRotate_CCW_triggered(); break;
        case 66: _t->on_actionRotate_CW_triggered(); break;
        case 67: _t->on_actionFree_Rotate_triggered(); break;
        case 68: _t->on_actionImage_Size_triggered(); break;
        case 69: _t->on_actionFilterbar_triggered(); break;
        case 70: _t->on_actionToolpalette_triggered(); break;
        case 71: _t->on_actionZoom_in_triggered(); break;
        case 72: _t->on_actionZoom_out_triggered(); break;
        case 73: _t->on_actionUndo_triggered(); break;
        case 74: _t->on_actionRedo_triggered(); break;
        case 75: _t->on_actionPrint_triggered(); break;
        case 76: _t->on_actionFull_screen_triggered(); break;
        case 77: _t->on_actionOriginal_size_triggered(); break;
        case 78: _t->on_actionSolarize_triggered(); break;
        case 79: _t->on_actionWave_triggered(); break;
        case 80: _t->on_actionImplode_triggered(); break;
        case 81: _t->on_actionSoften_triggered(); break;
        case 82: _t->on_actionBlur_triggered(); break;
        case 83: _t->on_actionSharpen_triggered(); break;
        case 84: _t->on_actionReinforce_triggered(); break;
        case 85: _t->on_actionImage_properties_triggered(); break;
        case 86: _t->on_actionAutomate_Batch_triggered(); break;
        case 87: _t->on_actionShow_selection_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 88: _t->on_actionCanvas_Size_triggered(); break;
        case 89: _t->on_actionRevert_triggered(); break;
        case 90: _t->on_actionBrightplus_triggered(); break;
        case 91: _t->on_actionBrightminus_triggered(); break;
        case 92: _t->on_actionContrastplus_triggered(); break;
        case 93: _t->on_actionContrastminus_triggered(); break;
        case 94: _t->on_actionGammaCorrectplus_triggered(); break;
        case 95: _t->on_actionGammaCorrectminus_triggered(); break;
        case 96: _t->on_actionSaturationplus_triggered(); break;
        case 97: _t->on_actionSaturationminus_triggered(); break;
        case 98: _t->on_actionOldPhoto_triggered(); break;
        case 99: _t->on_actionDustReduction_triggered(); break;
        case 100: _t->on_actionOutside_frame_triggered(); break;
        case 101: _t->on_actionEmboss_triggered(); break;
        case 102: _t->on_actionGaussian_triggered(); break;
        case 103: _t->on_actionImpulse_triggered(); break;
        case 104: _t->on_actionLaplacian_triggered(); break;
        case 105: _t->on_actionPoisson_triggered(); break;
        case 106: _t->on_actionMonoChromatic_triggered(); break;
        case 107: _t->on_actionEqualize_triggered(); break;
        case 108: _t->on_actionCrop_To_Center_triggered(); break;
        case 109: _t->on_actionAdd_Simple_Frame_triggered(); break;
        case 110: _t->on_actionMotion_blur_triggered(); break;
        case 111: _t->on_actionNormalize_triggered(); break;
        case 112: _t->on_action3D_frame_triggered(); break;
        case 113: _t->on_actionExplode_triggered(); break;
        case 114: _t->on_actionDespeckle_triggered(); break;
        case 115: _t->on_actionSepia_triggered(); break;
        case 116: _t->on_actionAuto_levels_triggered(); break;
        case 117: _t->on_actionAuto_contrast_triggered(); break;
        case 118: _t->batchProcess_fileProcessFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QImage>>(_a[2]))); break;
        case 119: _t->batchProcess_batchProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 120: _t->on_actionHue_variation_triggered(); break;
        case 121: _t->onHuePreviewChanged((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 122: _t->onPreviewTransparent((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 123: _t->onTransparentFinished(); break;
        case 124: _t->onTransparentAccepted(); break;
        case 125: _t->onTransparentRejected(); break;
        case 126: _t->on_actionGradient_triggered(); break;
        case 127: _t->on_actionCrop_triggered(); break;
        case 128: _t->on_actionStroke_Rect_triggered(); break;
        case 129: _t->on_actionFill_Rect_triggered(); break;
        case 130: _t->onSelectionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 131: _t->on_actionPaste_triggered(); break;
        case 132: _t->on_actionCopy_triggered(); break;
        case 133: _t->on_actionTransparent_colour_triggered(); break;
        case 134: _t->on_actionIndexed_Mode_triggered(); break;
        case 135: _t->on_actionRGB_Mode_triggered(); break;
        case 136: _t->on_actionDonate_triggered(); break;
        case 137: _t->on_actionAutomatic_Crop_triggered(); break;
        case 138: _t->on_actionNegative_triggered(); break;
        case 139: _t->on_actionBlack_and_white_triggered(); break;
        case 140: { bool _r = _t->fileExists((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 141: _t->on_actionOutside_drop_shadow_triggered(); break;
        case 142: _t->on_actionOpacity_triggered(); break;
        case 143: _t->on_actionPlugins_triggered(); break;
        case 144: _t->on_actionCheck_for_updates_triggered(); break;
        case 145: _t->onShowHotspotsTriggered(); break;
        case 146: _t->on_actionSelect_all_triggered(); break;
        case 147: _t->on_actionColour_Threshold_triggered(); break;
        case 148: _t->on_actionClearHistory_triggered(); break;
        case 149: _t->on_actionClearClipboard_triggered(); break;
        case 150: _t->on_actionDuplicate_triggered(); break;
        case 151: _t->on_actionShow_grid_triggered(); break;
        case 152: { QString _r = _t->prepareFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 153: { bool _r = _t->fileTypeSupported((*reinterpret_cast<std::add_pointer_t<QList<QByteArray>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 154: _t->getNextZoomFromScale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 155: _t->getPrevZoomFromScale((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 156: _t->onSafeQuitApp(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 153:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QByteArray> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 157)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 157;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 157)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 157;
    }
    return _id;
}
QT_WARNING_POP
