/********************************************************************************
** Form generated from reading UI file 'pointersettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.10.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_POINTERSETTINGSWIDGET_H
#define UI_POINTERSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PointerSettingsWidget
{
public:
    QToolButton *square_sel;
    QCheckBox *checkBoxStroke;
    QCheckBox *checkBoxFill;
    QToolButton *circle_sel;
    QSpinBox *strokeWidth;
    QLabel *label;

    void setupUi(QWidget *PointerSettingsWidget)
    {
        if (PointerSettingsWidget->objectName().isEmpty())
            PointerSettingsWidget->setObjectName("PointerSettingsWidget");
        PointerSettingsWidget->resize(134, 300);
        square_sel = new QToolButton(PointerSettingsWidget);
        square_sel->setObjectName("square_sel");
        square_sel->setGeometry(QRect(10, 10, 32, 32));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/assets/icons/selections/square_sel.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        square_sel->setIcon(icon);
        square_sel->setIconSize(QSize(24, 24));
        square_sel->setCheckable(true);
        square_sel->setChecked(true);
        checkBoxStroke = new QCheckBox(PointerSettingsWidget);
        checkBoxStroke->setObjectName("checkBoxStroke");
        checkBoxStroke->setGeometry(QRect(10, 110, 97, 22));
        checkBoxFill = new QCheckBox(PointerSettingsWidget);
        checkBoxFill->setObjectName("checkBoxFill");
        checkBoxFill->setGeometry(QRect(10, 140, 97, 22));
        circle_sel = new QToolButton(PointerSettingsWidget);
        circle_sel->setObjectName("circle_sel");
        circle_sel->setGeometry(QRect(50, 10, 32, 32));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/assets/icons/selections/circle_sel.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        circle_sel->setIcon(icon1);
        circle_sel->setCheckable(true);
        strokeWidth = new QSpinBox(PointerSettingsWidget);
        strokeWidth->setObjectName("strokeWidth");
        strokeWidth->setGeometry(QRect(10, 70, 111, 25));
        strokeWidth->setMinimum(1);
        label = new QLabel(PointerSettingsWidget);
        label->setObjectName("label");
        label->setGeometry(QRect(10, 50, 111, 16));

        retranslateUi(PointerSettingsWidget);

        QMetaObject::connectSlotsByName(PointerSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *PointerSettingsWidget)
    {
        PointerSettingsWidget->setWindowTitle(QCoreApplication::translate("PointerSettingsWidget", "Form", nullptr));
        square_sel->setText(QCoreApplication::translate("PointerSettingsWidget", "...", nullptr));
        checkBoxStroke->setText(QCoreApplication::translate("PointerSettingsWidget", "Stroke", nullptr));
        checkBoxFill->setText(QCoreApplication::translate("PointerSettingsWidget", "Fill", nullptr));
        circle_sel->setText(QCoreApplication::translate("PointerSettingsWidget", "...", nullptr));
        label->setText(QCoreApplication::translate("PointerSettingsWidget", "Stroke Width", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PointerSettingsWidget: public Ui_PointerSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_POINTERSETTINGSWIDGET_H
